@@ -3,3 +3,5 @@ from .bellingcat import BellingcatDownloader  # noqa
 from .ceninfores import CenInfoResDownloader  # noqa
 from .defmon import DefmonDownloader  # noqa
 from .geoconfirmed import GeoConfirmedDownloader  # noqa
+# from .reukraine import ReukraineDownloader  # noqa
+from .texty import TextyDownloader  # noqa
