@@ -1,5 +1,4 @@
 import json
-from urllib import request
 from typing import Any
 
 from .base import Downloader
@@ -12,8 +11,5 @@ DEFMON_ENDPOINT = 'https://widgets.scribblemaps.com/api/maps/nBT8ffpeGH/smjsonLo
 
 class DefmonDownloader(Downloader):
 
-    @staticmethod
-    def download() -> Any:
-        resp = request.urlopen(DEFMON_ENDPOINT)
-        data = json.loads(resp.read().decode('utf-8'))
-        return data
+    def download(self) -> Any:
+        return json.loads(self.request_url(DEFMON_ENDPOINT))
