@@ -1,13 +1,10 @@
 import json
-from urllib import request
 from typing import Any
 
 from .base import Downloader
 
 GEOCONFIRMED_ENDPOINT = 'https://geoconfirmed.azurewebsites.net/api/map/GetMap/Ukraine'  # noqa
 
-ENCODING = 'utf-8'
-
 class GeoConfirmedDownloader(Downloader):
     """
     @GeoConfirmed
@@ -15,8 +12,5 @@ class GeoConfirmedDownloader(Downloader):
     with blessing from author
     """
 
-    @staticmethod
-    def download() -> Any:
-        resp = request.urlopen(GEOCONFIRMED_ENDPOINT)
-        data = json.loads(resp.read().decode(ENCODING))
-        return data
+    def download(self) -> Any:
+        return json.loads(self.request_url(GEOCONFIRMED_ENDPOINT))
