@@ -29,3 +29,11 @@ def defmon_raw():
 @pytest.fixture
 def geoconfirmed_raw():
     return load(RAW_DATA_FILENAMES.GEOCONFIRMED)
+
+# @pytest.fixture
+# def reukraine_raw():
+#     return load(RAW_DATA_FILENAMES.REUKRAINE)
+
+@pytest.fixture
+def texty_raw():
+    return load(RAW_DATA_FILENAMES.TEXTY)
